@@ -1,6 +1,7 @@
 """ self-contained to write legacy pickle files """
 from __future__ import print_function
 
+
 def _create_sp_series():
 
     import numpy as np
@@ -53,12 +54,13 @@ def _create_sp_frame():
 def create_data():
     """ create the pickle data """
 
+    from distutils.version import LooseVersion
     import numpy as np
     import pandas
     from pandas import (Series,TimeSeries,DataFrame,Panel,
                         SparseSeries,SparseTimeSeries,SparseDataFrame,SparsePanel,
                         Index,MultiIndex,PeriodIndex,
-                        date_range,period_range,bdate_range,Timestamp)
+                        date_range,period_range,bdate_range,Timestamp,Categorical)
     nan = np.nan
 
     data = {
@@ -83,7 +85,8 @@ def create_data():
                   mi = Series(np.arange(5).astype(np.float64),index=MultiIndex.from_tuples(tuple(zip(*[[1,1,2,2,2],
                                                                                                     [3,4,3,4,5]])),
                                                                                            names=['one','two'])),
-                  dup=Series(np.arange(5).astype(np.float64), index=['A', 'B', 'C', 'D', 'A']))
+                  dup=Series(np.arange(5).astype(np.float64), index=['A', 'B', 'C', 'D', 'A']),
+                  cat=Series(Categorical(['foo', 'bar', 'baz'])))
 
     frame = dict(float = DataFrame(dict(A = series['float'], B = series['float'] + 1)),
                  int = DataFrame(dict(A = series['int']  , B = series['int']   + 1)),
@@ -92,13 +95,27 @@ def create_data():
                                 index=MultiIndex.from_tuples(tuple(zip(*[['bar','bar','baz','baz','baz'],
                                                                        ['one','two','one','two','three']])),
                                                              names=['first','second'])),
-                 dup = DataFrame(np.arange(15).reshape(5, 3).astype(np.float64),
-                                 columns=['A', 'B', 'A']))
+                 dup=DataFrame(np.arange(15).reshape(5, 3).astype(np.float64),
+                               columns=['A', 'B', 'A']),
+                 cat_onecol=DataFrame(dict(A=Categorical(['foo', 'bar']))),
+                 cat_and_float=DataFrame(dict(A=Categorical(['foo', 'bar', 'baz']),
+                                              B=np.arange(3))),
+    )
     panel = dict(float = Panel(dict(ItemA = frame['float'], ItemB = frame['float']+1)),
                  dup = Panel(np.arange(30).reshape(3, 5, 2).astype(np.float64),
                              items=['A', 'B', 'A']))
 
+    if LooseVersion(pandas.__version__) >= '0.14.1':
+        # Pre-0.14.1 versions generated non-unpicklable mixed-type frames and
+        # panels if their columns/items were non-unique.
+        mixed_dup_df = DataFrame(data)
+        mixed_dup_df.columns = list("ABCDA")
 
+        mixed_dup_panel = Panel(dict(ItemA=frame['float'], ItemB=frame['int']))
+        mixed_dup_panel.items = ['ItemA', 'ItemA']
+
+        frame['mixed_dup'] = mixed_dup_df
+        panel['mixed_dup'] = mixed_dup_panel
 
     return dict( series = series,
                  frame = frame,
