@@ -12,6 +12,7 @@ See LICENSE for the license
 #ifndef _PARSER_COMMON_H_
 #define _PARSER_COMMON_H_
 
+#include "Python.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -125,6 +126,7 @@ typedef enum {
     EAT_WHITESPACE,
     EAT_COMMENT,
     EAT_LINE_COMMENT,
+    WHITESPACE_LINE,
     FINISHED
 } ParserState;
 
@@ -202,10 +204,13 @@ typedef struct parser_t {
 
     void *skipset;
     int skip_footer;
+    double (*converter)(const char *, char **, char, char, char, int);
 
     // error handling
     char *warn_msg;
     char *error_msg;
+
+    int skip_empty_lines;
 } parser_t;
 
 
@@ -257,7 +262,9 @@ int64_t str_to_int64(const char *p_item, int64_t int_min,
                      int64_t int_max, int *error, char tsep);
 uint64_t str_to_uint64(const char *p_item, uint64_t uint_max, int *error);
 
-int P_INLINE to_double(char *item, double *p_value, char sci, char decimal, char tsep);
+double xstrtod(const char *p, char **q, char decimal, char sci, char tsep, int skip_trailing);
+double precise_xstrtod(const char *p, char **q, char decimal, char sci, char tsep, int skip_trailing);
+double round_trip(const char *p, char **q, char decimal, char sci, char tsep, int skip_trailing);
 int P_INLINE to_complex(char *item, double *p_real, double *p_imag, char sci, char decimal);
 int P_INLINE to_longlong(char *item, long long *p_value);
 int P_INLINE to_longlong_thousands(char *item, long long *p_value, char tsep);
