@@ -2,6 +2,7 @@ from pandas.compat import StringIO, callable
 from pandas.lib import cache_readonly
 import sys
 import warnings
+from functools import wraps
 
 
 def deprecate(name, alternative, alt_name=None):
@@ -13,6 +14,82 @@ def deprecate(name, alternative, alt_name=None):
         return alternative(*args, **kwargs)
     return wrapper
 
+
+def deprecate_kwarg(old_arg_name, new_arg_name, mapping=None):
+    """Decorator to deprecate a keyword argument of a function
+
+    Parameters
+    ----------
+    old_arg_name : str
+        Name of argument in function to deprecate
+    new_arg_name : str
+        Name of prefered argument in function
+    mapping : dict or callable
+        If mapping is present, use it to translate old arguments to
+        new arguments.  A callable must do its own value checking;
+        values not found in a dict will be forwarded unchanged.
+
+    Examples
+    --------
+    The following deprecates 'cols', using 'columns' instead
+
+    >>> @deprecate_kwarg(old_arg_name='cols', new_arg_name='columns')
+    ... def f(columns=''):
+    ...     print(columns)
+    ...
+    >>> f(columns='should work ok')
+    should work ok
+    >>> f(cols='should raise warning')
+    FutureWarning: cols is deprecated, use columns instead
+      warnings.warn(msg, FutureWarning)
+    should raise warning
+    >>> f(cols='should error', columns="can't pass do both")
+    TypeError: Can only specify 'cols' or 'columns', not both
+    >>> @deprecate_kwarg('old', 'new', {'yes': True, 'no', False})
+    ... def f(new=False):
+    ...     print('yes!' if new else 'no!')
+    ...
+    >>> f(old='yes')
+    FutureWarning: old='yes' is deprecated, use new=True instead
+      warnings.warn(msg, FutureWarning)
+    yes!
+
+    """
+    if mapping is not None and not hasattr(mapping, 'get') and \
+            not callable(mapping):
+        raise TypeError("mapping from old to new argument values "
+                        "must be dict or callable!")
+    def _deprecate_kwarg(func):
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            old_arg_value = kwargs.pop(old_arg_name, None)
+            if old_arg_value is not None:
+                if mapping is not None:
+                    if hasattr(mapping, 'get'):
+                        new_arg_value = mapping.get(old_arg_value,
+                                                    old_arg_value)
+                    else:
+                        new_arg_value = mapping(old_arg_value)
+                    msg = "the %s=%r keyword is deprecated, " \
+                          "use %s=%r instead" % \
+                          (old_arg_name, old_arg_value,
+                           new_arg_name, new_arg_value)
+                else:
+                    new_arg_value = old_arg_value
+                    msg = "the '%s' keyword is deprecated, " \
+                          "use '%s' instead" % (old_arg_name, new_arg_name)
+                warnings.warn(msg, FutureWarning)
+                if kwargs.get(new_arg_name, None) is not None:
+                    msg = "Can only specify '%s' or '%s', not both" % \
+                      (old_arg_name, new_arg_name)
+                    raise TypeError(msg)
+                else:
+                    kwargs[new_arg_name] = new_arg_value
+            return func(*args, **kwargs)
+        return wrapper
+    return _deprecate_kwarg
+
+
 # Substitution and Appender are derived from matplotlib.docstring (1.1.0)
 # module http://matplotlib.sourceforge.net/users/license.html
 
@@ -181,3 +258,29 @@ def knownfailureif(fail_condition, msg=None):
         return nose.tools.make_decorator(f)(knownfailer)
 
     return knownfail_decorator
+
+def make_signature(func) :
+    """
+    Returns a string repr of the arg list of a func call, with any defaults
+
+    Examples
+    --------
+
+    >>> def f(a,b,c=2) :
+    >>>     return a*b*c
+    >>> print(_make_signature(f))
+    a,b,c=2
+    """
+    from inspect import getargspec
+    spec = getargspec(func)
+    if spec.defaults == None :
+        n_wo_defaults = len(spec.args)
+        defaults = ('',) * n_wo_defaults
+    else :
+        n_wo_defaults = len(spec.args) - len(spec.defaults)
+        defaults = ('',) * n_wo_defaults + spec.defaults
+    args = []
+    for i, (var, default) in enumerate(zip(spec.args, defaults)) :
+        args.append(var if default=='' else var+'='+repr(default))
+    return args, spec.args
+
